@@ -13,10 +13,10 @@
 
 (defvar base16-catppuccin-frappe-theme-colors
   '(:base00 "#303446"
-    :base01 "#292c3c"
-    :base02 "#414559"
-    :base03 "#51576d"
-    :base04 "#626880"
+    :base01 "#414559"
+    :base02 "#51576d"
+    :base03 "#737994"
+    :base04 "#a5adce"
     :base05 "#c6d0f5"
     :base06 "#f2d5cf"
     :base07 "#babbf1"
