@@ -12,22 +12,22 @@
 (require 'base16-theme)
 
 (defvar base16-charcoal-dark-theme-colors
-  '(:base00 "#120f09"
-    :base01 "#1e1812"
-    :base02 "#35291d"
-    :base03 "#66553f"
-    :base04 "#a28662"
-    :base05 "#c0a179"
-    :base06 "#d6b891"
-    :base07 "#292016"
-    :base08 "#887254"
-    :base09 "#d6b891"
-    :base0A "#c0a179"
-    :base0B "#927a60"
-    :base0C "#a28662"
-    :base0D "#d6b891"
-    :base0E "#a28662"
-    :base0F "#887254")
+  '(:base00 "#0f0b05"
+    :base01 "#231b0e"
+    :base02 "#2a2012"
+    :base03 "#57462c"
+    :base04 "#a88c62"
+    :base05 "#c3a983"
+    :base06 "#dec8a7"
+    :base07 "#231b0e"
+    :base08 "#a88c62"
+    :base09 "#dec8a7"
+    :base0A "#dec8a7"
+    :base0B "#dec8a7"
+    :base0C "#dec8a7"
+    :base0D "#c3a983"
+    :base0E "#a88c62"
+    :base0F "#876e48")
   "All colors for Base16 Charcoal Dark are defined here.")
 
 ;; Define the theme
