@@ -4,7 +4,7 @@
 ;; Base16: (https://github.com/tinted-theming/home)
 
 ;;; Authors:
-;; Scheme: cjayross (https://github.com/cjayross)
+;; Scheme: cjayross (https://github.com/cjayross), Tinted Theming (https://github.com/tinted-theming)
 ;; Template: Kaleb Elwert <belak@coded.io>
 
 ;;; Code:
@@ -13,15 +13,15 @@
 
 (defvar base16-edge-dark-theme-colors
   '(:base00 "#262729"
-    :base01 "#88909f"
-    :base02 "#b7bec9"
-    :base03 "#3e4249"
-    :base04 "#73b3e7"
-    :base05 "#b7bec9"
-    :base06 "#d390e7"
-    :base07 "#3e4249"
+    :base01 "#313235"
+    :base02 "#3d3f42"
+    :base03 "#4a4c4f"
+    :base04 "#95989d"
+    :base05 "#afb2b5"
+    :base06 "#caccce"
+    :base07 "#e4e5e6"
     :base08 "#e77171"
-    :base09 "#e77171"
+    :base09 "#eba31a"
     :base0A "#dbb774"
     :base0B "#a1bf78"
     :base0C "#5ebaa5"
