@@ -15,8 +15,8 @@
   '(:base00 "#0f0f0f"
     :base01 "#191919"
     :base02 "#262626"
-    :base03 "#4c4c4c"
-    :base04 "#ac8a8c"
+    :base03 "#393939"
+    :base04 "#4c4c4c"
     :base05 "#cacaca"
     :base06 "#e7e7e7"
     :base07 "#f0f0f0"
