@@ -4,7 +4,7 @@
 ;; Base16: (https://github.com/tinted-theming/home)
 
 ;;; Authors:
-;; Scheme: Jon Leopard (http://github.com/jonleopard), based on PaperColor Theme (https://github.com/NLKNguyen/papercolor-theme)
+;; Scheme: Jon Leopard (http://github.com/jonleopard), Tinted Theming (https://github.com/tinted-theming), based on PaperColor Theme (https://github.com/NLKNguyen/papercolor-theme)
 ;; Template: Kaleb Elwert <belak@coded.io>
 
 ;;; Code:
@@ -13,21 +13,21 @@
 
 (defvar base16-papercolor-light-theme-colors
   '(:base00 "#eeeeee"
-    :base01 "#af0000"
-    :base02 "#008700"
-    :base03 "#5f8700"
-    :base04 "#0087af"
-    :base05 "#444444"
-    :base06 "#005f87"
-    :base07 "#878787"
-    :base08 "#bcbcbc"
-    :base09 "#d70000"
-    :base0A "#d70087"
-    :base0B "#8700af"
-    :base0C "#d75f00"
-    :base0D "#d75f00"
-    :base0E "#005faf"
-    :base0F "#005f87")
+    :base01 "#c4c4c4"
+    :base02 "#9e9e9e"
+    :base03 "#858585"
+    :base04 "#6b6b6b"
+    :base05 "#5e5e5e"
+    :base06 "#525252"
+    :base07 "#444444"
+    :base08 "#d70000"
+    :base09 "#d75f00"
+    :base0A "#d75f00"
+    :base0B "#008700"
+    :base0C "#0087af"
+    :base0D "#005f87"
+    :base0E "#8700af"
+    :base0F "#af0000")
   "All colors for Base16 PaperColor Light are defined here.")
 
 ;; Define the theme
