@@ -4,7 +4,7 @@
 ;; Base16: (https://github.com/tinted-theming/home)
 
 ;;; Authors:
-;; Scheme: Tiagovla (https://github.com/tiagovla/)
+;; Scheme: Jamy Golden (https://github.com/JamyGolden), Based on Tokyodark.nvim (https://github.com/tiagovla/tokyodark.nvim)
 ;; Template: Kaleb Elwert <belak@coded.io>
 
 ;;; Code:
@@ -13,20 +13,20 @@
 
 (defvar base16-tokyodark-theme-colors
   '(:base00 "#11121d"
-    :base01 "#151621"
-    :base02 "#43444f"
-    :base03 "#393a45"
-    :base04 "#1b1c27"
-    :base05 "#abb2bf"
-    :base06 "#555661"
-    :base07 "#2c2d38"
-    :base08 "#a485dd"
-    :base09 "#a485dd"
-    :base0A "#7199ee"
-    :base0B "#d7a65f"
-    :base0C "#a485dd"
-    :base0D "#95c561"
-    :base0E "#ee6d85"
+    :base01 "#212234"
+    :base02 "#212234"
+    :base03 "#353945"
+    :base04 "#4a5057"
+    :base05 "#a0a8cd"
+    :base06 "#abb2bf"
+    :base07 "#bcc2dc"
+    :base08 "#ee6d85"
+    :base09 "#f6955b"
+    :base0A "#d7a65f"
+    :base0B "#95c561"
+    :base0C "#9fbbf3"
+    :base0D "#7199ee"
+    :base0E "#a485dd"
     :base0F "#773440")
   "All colors for Base16 Tokyodark are defined here.")
 
